@@ -110,13 +110,14 @@ def parse_fulladdress(fulladdress):
         info["address"] = fulladdress
         return info
     rest, info["zip"] = fulladdress.rsplit(" ", 1)
-    if len(info["zip"]) == 2: 
+    if not all(map(lambda x:x in "0123456789-", info["zip"])): 
         info['state'] = info['zip']
         info['zip'] = ''
     if ", " not in  rest:
         info["address"] = rest
         return info
-    rest, info["state"] = rest.rsplit(", ", 1)
+    if not info["state"]:
+        rest, info["state"] = rest.rsplit(", ", 1)
     if ", " not in  rest:
         info["address"] = rest
         return info
@@ -126,4 +127,56 @@ def parse_fulladdress(fulladdress):
     for f in ('address', 'state', 'city', 'zip'):
         if info[f] and info[f][-1] in (',',';','.'):
             info[f] = info[f][:-1]
-    return info
\ No newline at end of file
+    return info
+
+def remove_aka(fullname):
+    """ Removes AKA from the fullname given """
+    for aka in ("AKA ", " AKA", "A.K.A", "A/K/A"):
+        if aka in fullname.upper():
+            fullname = fullname.split(aka,1)[0]
+    return fullname
+
+
+def is_person(fullname):
+    """ Checks whether a name given is person's name """
+    return not (any(map(lambda e:fullname.upper().strip().endswith(e), 
+                            [' NA', 'LLC', ' INC', ' CO', ' CORP', 'LLP', 'LTD', 'LLC', 'INC.', ' CO.', ' CORP.', 'LLP.', 'LTD.' , ' LLE', ' LLE.', ' TRUST'])) or \
+               any(map(lambda e:e in fullname.upper(), ['ACADEM', 'HOSPITAL', 'COMPANY', 'CO.', 'SERVICES', 'AUTHORITY', 'ASSOC', 'N.A.', ' BANK', ' BANK.',  
+                                    ' INC', 'LLC', ' CORP', 'LLP', 'LLC', 'LTD', 'STATE', 'CITY', 'COUNTY', ' TRUST ', ' COURT ', 'DPT', 'DPT.'
+                                    'TOWNSHIP', 'GOVERNMENT', 'UNIVERSITY', "UNION", " BANK ", "COOPERATIVE", "ENTERPR", "DISTRICT", 
+                                    "COMMONWEALTH", "CONDOMINIUM", "VILLAGE", "SHOP", "APARTMENTS", "&", "DBA", " AND ", "BUREAU", "TWP", "MARKET",
+                                    "STUDIO", "ASSOC", ' TRUST ', 'NETWORK', 'LIMITED', 'DEPARTMENT', 'UNIT', 'CREDIT', 'TENANT', 'UNKNOWN', 'N/A'])))
+
+def parse_city_state_zip(city_state_zip):
+    """ Parses city_state_zip into a dict """
+    info = dict(city="", state="", zip="")
+    try:
+        info["city"], info["state"], info["zip"] = city_state_zip.rsplit(" ", 2)
+    except:
+        try:
+            p1, p2 = city_state_zip.rsplit(" ", 1)
+            # check if p1 is US zip :
+            if all(map(lambda x:x in "0123456789-", p2)):
+                info['state'], info['zip'] = p1, p2
+            else:
+                info['city'], info['state'] = p1, p2
+        except:
+            info['city'] = city_state_zip
+    for f in ('city', 'state', 'zip'):
+        info[f] = info[f].replace(u'\xa0','')
+    info['state'] = info['state'].upper()
+    return info
+
+def normalize_address(address):
+    """ Address must start with PO, RR, or a number """
+    addr_headers = ('0','1','2','3','4','5','6','7','8','9',
+                    'PO ', "P O", "P.O.", "P. O.", 
+                    'RR ', "R R", "R.R.", "R. R.")
+    addr = address.strip().upper() 
+    for suffix in addr_headers:
+        if addr.startswith(suffix):
+            return addr    
+    for suffix in addr_headers:
+        if suffix in addr:
+            return addr[addr.find(suffix):]    
+    return address
\ No newline at end of file
